#!/bin/sh
# changedetection v1.0@geimist

# Definition der Variablen:
    EMPFAENGER=empfaenger@domain.de
    ABSENDER='From: Diskstation <admin@domain.de>'


#--------------------------------------------- AB HIER NICHTS MEHR ÄNDERN ---------------------------------------------
APPDIR=$(cd $(dirname $0);pwd)
ERROR=0

if [ ! -d "${APPDIR}/tmp/" ] ; then
    mkdir "${APPDIR}/tmp"
fi
if [ ! -d "${APPDIR}/change_detected/" ] ; then
    mkdir "${APPDIR}/change_detected"
fi

while read i # Quelle zeilenweise einlesen
    do 
        if [ "$i" == "" ]; then
            continue
        elif echo "$i" | grep -q "#" ; then # ändern auf nur mit # beginnenden Zeilen
            continue
        fi
        
        NAME=`echo $i | awk '{print $1}'`
        LINK=`echo $i | awk '{print $2}' | sed 's/\"//g'`
        echo -e; echo "=> ${NAME}:"
        
        if [ -f "${APPDIR}/tmp/${NAME}.txt" ] ; then
            mv "${APPDIR}/tmp/${NAME}.txt" "${APPDIR}/tmp/${NAME}_old.txt"
        fi
        
        # 1.: lese bisherigen Hash
        #---------------------------------------------
        hash1=`cat "${APPDIR}/tmp/${NAME}_old.txt" | cksum | awk '{print $1}'`
        echo "alter Hash ist:       $hash1"
        
        # 2.: lade aktuelle index.html
        #---------------------------------------------
        machinetyp=`uname --machine`
	    if [ $machinetyp = "x86_64" ]; then  
            ${APPDIR}/links_APP/bin/links -dump "$LINK" -memory-cache-size 1 -ssl.certificates 0 -codepage "utf-8" -http.fake-firefox 1 -anonymous > "${APPDIR}/tmp/${NAME}.txt"
        else
            links -dump "$LINK" -memory-cache-size 1 -ssl.certificates 0 -codepage "utf-8" -http.fake-firefox 1 -anonymous > "${APPDIR}/tmp/${NAME}.txt"
        fi
        # Links von synocommunity: https://synocommunity.com/package/links
        # manual: https://www.mankier.com/1/links2
        # Parameter "ssl.certificates 0" in Datei ~/.links/links.cfg notwendig oder direkt übergeben (warum können Certs nicht validiert werden?)
        
        filesize=$(ls -l "${APPDIR}/tmp/${NAME}.txt" | awk '{ print $5 }')
        
        if [ "$filesize" -eq 0 ]; then
            echo "Download fehlgeschlagen - ${NAME} wird übersprungen"
            mv "${APPDIR}/tmp/${NAME}_old.txt" "${APPDIR}/tmp/${NAME}.txt" # alte Datei wiederherstellen
            continue
        fi

        # 3.: ermittle aktuellen Hash
        #---------------------------------------------
        hash2=`cat "${APPDIR}/tmp/${NAME}.txt" | cksum | awk '{print $1}'`
        echo "aktueller Hash ist:   $hash2"
        
        # 4.: vergleiche Hashes, ggf. Änderung mailen
        #---------------------------------------------
        if [ $hash1 -eq $hash2 ]; then
            echo "keine Änderung für ${NAME} gefunden"
            rm "${APPDIR}/tmp/${NAME}_old.txt"
        else
        	if [ -f "${APPDIR}/tmp/${NAME}_old.txt" ] ; then
                VARDIFF=`diff "${APPDIR}/tmp/${NAME}_old.txt" "${APPDIR}/tmp/${NAME}.txt"`
                
                message="es wurden Änderungen auf der Website $LINK gefunden!
                
                Änderungen:
                $VARDIFF"
                
            	echo $message
            	subject="! ! ! ACHTUNG ! ! ! - Änderung für ${NAME} gefunden"
                /usr/bin/php -r "mail('$EMPFAENGER', '$subject', '$message', '$ABSENDER');"
            	synodsmnotify @administrators "! ! Änderung ${NAME} ! !" "$message"
            	
                mv "${APPDIR}/tmp/${NAME}_old.txt" "${APPDIR}/change_detected/${NAME}_`date +%Y`-`date +%m`-`date +%d`_`date +%H`-`date +%M`_before.txt"
                cp "${APPDIR}/tmp/${NAME}.txt" "${APPDIR}/change_detected/${NAME}_`date +%Y`-`date +%m`-`date +%d`_`date +%H`-`date +%M`_current.txt"
            fi
        fi
    done < "${APPDIR}/SITES.txt"
    
    if [ "$ERROR" -eq 1 ]; then
        exit 1
    fi
    
exit
    